abacusai.inferred_database_column_to_feature_mappings — AbacusAI documentation

# abacusai.inferred_database_column_to_feature_mappings

## Classes

`InferredDatabaseColumnToFeatureMappings` | Autocomplete mappings for database to connector columns

## Module Contents

class abacusai.inferred_database_column_to_feature_mappings.InferredDatabaseColumnToFeatureMappings(client, databaseColumnToFeatureMappings={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Autocomplete mappings for database to connector columns

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - databaseColumnToFeatureMappings (DatabaseColumnFeatureMapping) – Database columns feature mappings

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict